summaryrefslogtreecommitdiff
path: root/js_tests/admin/SelectBox.test.js
diff options
context:
space:
mode:
Diffstat (limited to 'js_tests/admin/SelectBox.test.js')
-rw-r--r--js_tests/admin/SelectBox.test.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/js_tests/admin/SelectBox.test.js b/js_tests/admin/SelectBox.test.js
index cb0259d12c..23c057c364 100644
--- a/js_tests/admin/SelectBox.test.js
+++ b/js_tests/admin/SelectBox.test.js
@@ -1,17 +1,17 @@
/* global module, test, SelectBox */
/* eslint global-strict: 0, strict: 0 */
'use strict';
-module('admin.SelectBox');
+QUnit.module('admin.SelectBox');
-test('init: no options', function(assert) {
+QUnit.test('init: no options', function(assert) {
var $ = django.jQuery;
$('<select id="id"></select>').appendTo('#qunit-fixture');
SelectBox.init('id');
assert.equal(SelectBox.cache.id.length, 0);
});
-test('filter', function(assert) {
+QUnit.test('filter', function(assert) {
var $ = django.jQuery;
$('<select id="id"></select>').appendTo('#qunit-fixture');
$('<option value="0">A</option>').appendTo('#id');
@@ -1,17 +1,17 @@
-/* global module, test, SelectBox */
+/* global QUnit, SelectBox */
/* eslint global-strict: 0, strict: 0 */
'use strict';